﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinDataSource;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.FormattedLinkLabel;
using Infragistics.Win.Printing;

namespace GridTest
{
    public partial class TooltipBackgroundTestForm : Form
    {
        private UltraGridPrintDocument _gridPrintDocument;

        private Infragistics.Win.Appearance _alternateCellAppearance;
        private Infragistics.Win.Appearance _alternateOrderRowAppearance;
        private Infragistics.Win.Appearance _normalOrderRowAppearance;

        public TooltipBackgroundTestForm()
        {
            _alternateOrderRowAppearance = CreateDefaultAppearance();
            _alternateOrderRowAppearance.BackColor = Color.FromArgb(215, 0, 0);
            _alternateOrderRowAppearance.BackColorAlpha = Alpha.UseAlphaLevel;
            _alternateOrderRowAppearance.AlphaLevel = 10;

            _alternateCellAppearance = new Infragistics.Win.Appearance();
            _alternateCellAppearance.BackColor = Color.FromArgb(0, 0, 0);
            _alternateCellAppearance.BackColorAlpha = Alpha.UseAlphaLevel;
            _alternateCellAppearance.AlphaLevel = 20;
            _alternateCellAppearance.ForegroundAlpha = Alpha.Opaque;
            _alternateCellAppearance.ImageAlpha = Alpha.Opaque;
            _alternateCellAppearance.ImageVAlign = VAlign.Top;
            _alternateCellAppearance.ImageHAlign = HAlign.Center;

            _normalOrderRowAppearance = new Infragistics.Win.Appearance();

            _normalOrderRowAppearance.ForeColor = Color.Black;
            _normalOrderRowAppearance.ForegroundAlpha = Alpha.Opaque;
            _normalOrderRowAppearance.ImageAlpha = Alpha.Opaque;

            InitializeComponent();

            System.Data.DataSet dsDataGrid = new DataSet("DataGrid");

            string filePath = "Sample.xml";
            dsDataGrid.ReadXml(filePath);

            this.ultraGrid1.DataSource = dsDataGrid;
            this.ultraGrid1.DataBind();

            InitializeGridPrintDocument();
            
        }

        private static Infragistics.Win.Appearance CreateDefaultAppearance()
        {
            Infragistics.Win.Appearance appearance = new Infragistics.Win.Appearance();
            appearance.BackColorAlpha = Alpha.Opaque;
            appearance.BorderAlpha = Alpha.Opaque;
            appearance.ForegroundAlpha = Alpha.Opaque;
            appearance.ImageAlpha = Alpha.Opaque;
            appearance.ForeColor = Color.Black;
            appearance.ForeColorDisabled = Color.LightGray;

            return appearance;
        }

        private void Close_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;
            e.Layout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;

            e.Layout.ViewStyleBand = Infragistics.Win.UltraWinGrid.ViewStyleBand.Horizontal;
            e.Layout.Override.RowSizing = RowSizing.AutoFree;
            e.Layout.Override.CellMultiLine = DefaultableBoolean.True;
            e.Layout.Override.RowSizingAutoMaxLines = 5;

            e.Layout.Override.AllowAddNew = AllowAddNew.No;
            e.Layout.Override.AllowDelete = DefaultableBoolean.False;
            e.Layout.Override.AllowRowLayoutCellSizing = RowLayoutSizing.None;
            e.Layout.Override.CellClickAction = CellClickAction.RowSelect;
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;
            e.Layout.Override.CellPadding = 0;
            e.Layout.Override.RowSelectors = DefaultableBoolean.False;

            e.Layout.InterBandSpacing = 0;
            e.Layout.Override.RowSpacingAfter = 0;
            e.Layout.Override.SelectTypeRow = SelectType.Single;

            e.Layout.Override.AllowColSizing = AllowColSizing.Free;
            e.Layout.Override.AllowColMoving = AllowColMoving.NotAllowed;
            e.Layout.Override.AllowColSwapping = AllowColSwapping.NotAllowed;

            e.Layout.AutoFitStyle = AutoFitStyle.None;

            e.Layout.Override.RowAlternateAppearance = _alternateOrderRowAppearance;

            e.Layout.Bands[0].Columns["city"].CellAppearance = _alternateCellAppearance;
            e.Layout.Bands[0].Columns["zip"].CellAppearance = _alternateCellAppearance;

            e.Layout.Bands[0].Columns["street"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.FormattedText;
        }

        private void ultraGrid1_InitializePrint(object sender, CancelablePrintEventArgs e)
        {
            e.PrintLayout.Override.ResetRowSizingAutoMaxLines();

            //Fit width to pages
            e.DefaultLogicalPageLayoutInfo.FitWidthToPages = 1;

            // Set up the header, 
            e.DefaultLogicalPageLayoutInfo.PageHeaderHeight = 20;
            e.DefaultLogicalPageLayoutInfo.PageHeaderBorderStyle = UIElementBorderStyle.None;

            // Set the ClippingOverride to Yes.
            e.DefaultLogicalPageLayoutInfo.ClippingOverride = ClippingOverride.Yes;


            e.PrintDocument.DocumentName = "My Report";
        }

        private void InitializeGridPrintDocument()
        {
            _gridPrintDocument = new UltraGridPrintDocument();
            _gridPrintDocument.Grid = this.ultraGrid1;

            // Initialize the text that will appear in the footer.
            // this can be replaceable tokens that will insert the
            // time, page number, etc.
            string textLeft = "Requested by me";
            string textRight = DateTime.Today.ToString();

            _gridPrintDocument.Footer.TextLeft = textLeft;
            _gridPrintDocument.Footer.TextRight = textRight;
            _gridPrintDocument.Footer.BorderStyle = UIElementBorderStyle.Solid;
            _gridPrintDocument.Footer.Appearance.BackColor = Color.LightGray;
            _gridPrintDocument.Footer.Margins.Top = 5;
            _gridPrintDocument.Footer.Margins.Bottom = 5;

        }

        private void printPreviewBtn_Click(object sender, EventArgs e)
        {

            UltraPrintPreviewDialog ultraPrintPreviewDialog1 = new UltraPrintPreviewDialog();
            ultraPrintPreviewDialog1.Document = _gridPrintDocument;

            ultraPrintPreviewDialog1.FindForm().Focus();
            ultraPrintPreviewDialog1.FindForm().WindowState = FormWindowState.Maximized;

            ultraPrintPreviewDialog1.ShowDialog();
        }

    }
}
